package com.diagbot.repository;

import com.diagbot.entity.node.ClinicalFinding;
import com.diagbot.entity.node.EntityInfo;
import org.springframework.data.neo4j.annotation.Query;
import org.springframework.data.neo4j.repository.Neo4jRepository;
import org.springframework.data.repository.query.Param;

import java.util.List;


public interface ClinicalFindingRepository extends Neo4jRepository<ClinicalFinding, Long> {

    List<ClinicalFinding> findByNameIs(String name);

    List<ClinicalFinding> findByNameIn(List<String> names);

    List<ClinicalFinding> findByNameContaining(String name);

    @Query("merge (n:临床表现{name:{name}})  " +
            "on create set  " +
            "n.拼音编码={pycode}," +
            "n.静态知识标识={is_kl}," +
            "n.状态={status}," +
            "n.最大值={maxValue}," +
            "n.最小值={minValue}," +
            "n.范围={range}," +
            "n.单位={unit}, " +
            "n.临床表现指标={indication} " +
            "on match set  " +
            "n.拼音编码={pycode}," +
            "n.静态知识标识={is_kl}," +
            "n.状态={status}," +
            "n.最大值={maxValue}," +
            "n.最小值={minValue}," +
            "n.范围={range}," +
            "n.单位={unit}, " +
            "n.临床表现指标={indication} " +
            "RETURN n,[ (n)-[r]->(m) | [ r, m ] ], ID(n)\n")
    ClinicalFinding createOrUpdate(@Param("name") String name,
                                   @Param("is_kl") Integer is_kl,
                                   @Param("pycode") String pycode,
                                   @Param("status") Integer status,
                                   @Param("maxValue") Double maxValue,
                                   @Param("minValue") Double minValue,
                                   @Param("range") Integer range,
                                   @Param("unit") String unit,
                                   @Param("indication") String indication);

    @Query("create (n:临床表现) \n" +
            "set  " +
            "n.name = :#{#entityInfo.name}," +
            "n.拼音编码 = :#{#entityInfo.pycode}," +
            "n.静态知识标识 = :#{#entityInfo.is_kl}," +
            "n.状态 = :#{#entityInfo.status}" +
            "\n" +
            "RETURN n,[ (n)-[r]->(m) | [ r, m ] ], ID(n)\n")
    ClinicalFinding create(@Param("entityInfo") EntityInfo entityInfo);
}
